@@ -24,7 +24,7 @@ except ImportError:
     mysql = None
 
 
-__version__ = "0.6.2"
+__version__ = "0.6.4"
 __all__ = [
     "Association",
     "Database",
@@ -245,6 +245,13 @@ class fn(metaclass=FunctionMetaclass):
         :param schema: The schema.
         :type schema: Schema
         """
+        if schema.allow_wildcard_select is False:
+            raise QueryError(
+                "Wildcard selects are disabled for schema: "
+                f"`{schema.__tablename__}`"
+                ", please specify fields."
+            )
+
         return Clause(f"{schema.__tablename__}.*", ())
 
 
@@ -418,10 +425,17 @@ class SchemaMetaclass(type):
 
 
 class Schema(metaclass=SchemaMetaclass):
+    """
+    A schema representation of a database table.
+
+    :ivar allow_wildcard_select: Determines if wildcards can be used when 'selecting'.
+    """
 
     _database_ = None
     __tablename__ = None
 
+    allow_wildcard_select = True
+
     @classmethod
     def _cast(cls, updating, row):
         # Allow you to use a Field as key
@@ -590,6 +604,13 @@ def _do_preload_query(db, cardinality, query, value):
 
 def _do_preload(db, association, row):
     if isinstance(association, _Association):
+        if association.schema.allow_wildcard_select is False:
+            raise QueryError(
+                "Wildcard selects are disabled for schema: "
+                f"`{association.schema.__tablename__}`"
+                ", please specify fields."
+            )
+
         query = f"""
             select * from {association.schema.__tablename__}
             where {association.field} = %s
@@ -600,12 +621,24 @@ def _do_preload(db, association, row):
         )
 
     aso, values = list(association.items())[0]
+
+    if row.get(aso.owner) is None:
+        return aso.name, None
+
     associations = [
         v for v in values if isinstance(v, _Association) or isinstance(v, dict)
     ]
+
     fields = [v.name for v in values if isinstance(v, Field)]
     select = ", ".join(fields) if len(fields) > 0 else "*"
 
+    if aso.schema.allow_wildcard_select is False and select == "*":
+        raise QueryError(
+            "Wildcard selects are disabled for schema: "
+            f"`{aso.schema.__tablename__}`"
+            ", please specify fields."
+        )
+
     query = f"""
         select {select} from {aso.schema.__tablename__}
         where {aso.field} = %s
@@ -613,6 +646,9 @@ def _do_preload(db, association, row):
 
     new_row = _do_preload_query(db, aso.cardinality, query, row[aso.owner])
 
+    if new_row is None:
+        return aso.name, None
+
     for field_aso in associations:
         name, field = _do_preload(db, field_aso, new_row)
         new_row[name] = field
@@ -646,6 +682,14 @@ class Query(metaclass=QueryMetaclass):
         params = []
 
         if len(args) < 1:
+
+            if self.schema.allow_wildcard_select is False:
+                raise QueryError(
+                    "Wildcard selects are disabled for schema: "
+                    f"`{self.schema.__tablename__}`"
+                    ", please specify fields."
+                )
+
             query += "*"
         else:
             for arg in args:
